-- Drop the table if it exists
DROP TABLE IF EXISTS account;

-- Create the account table
CREATE TABLE account (
  db_id BIGSERIAL PRIMARY KEY,  -- Use BIGSERIAL for auto-incrementing bigint
  id BIGINT NOT NULL,
  creation_height INTEGER NOT NULL,
  public_key BYTEA,  -- Use BYTEA for varbinary
  key_height INTEGER,  -- Nullable integer
  name VARCHAR(100),  -- No need for COLLATE in PostgreSQL unless specific collation is required
  description TEXT,  -- TEXT type is the same in PostgreSQL
  height INTEGER NOT NULL,
  latest BOOLEAN NOT NULL DEFAULT TRUE  -- Use BOOLEAN instead of tinyint(1)
);

-- Create unique and regular indexes
CREATE UNIQUE INDEX account_id_height_idx ON account (id, height);
CREATE INDEX account_id_latest_idx ON account (id, latest);


CREATE TABLE block (
  db_id BIGSERIAL PRIMARY KEY,
  id BIGINT NOT NULL UNIQUE,
  version INTEGER NOT NULL,
  timestamp INTEGER NOT NULL,
  previous_block_id BIGINT DEFAULT NULL,
  total_amount BIGINT NOT NULL,
  total_fee BIGINT NOT NULL,
  payload_length INTEGER NOT NULL,
  generator_public_key BYTEA NOT NULL,
  previous_block_hash BYTEA DEFAULT NULL,
  next_block_id BIGINT DEFAULT NULL,
  height INTEGER NOT NULL UNIQUE,
  generation_signature BYTEA NOT NULL,
  block_signature BYTEA NOT NULL,
  payload_hash BYTEA NOT NULL,
  generator_id BIGINT NOT NULL,
  nonce BIGINT NOT NULL,
  sm1 BIGINT DEFAULT NULL,
  sm1_ba BIGINT DEFAULT NULL,
  sm2 BIGINT DEFAULT NULL,
  sm2_ba BIGINT DEFAULT NULL,
  sm3 BIGINT DEFAULT NULL,
  sm3_ba BIGINT DEFAULT NULL,
  sm4 BIGINT DEFAULT NULL,
  sm4_ba BIGINT DEFAULT NULL,
  sm5 BIGINT DEFAULT NULL,
  sm5_ba BIGINT DEFAULT NULL,
  sm6 BIGINT DEFAULT NULL,
  sm6_ba BIGINT DEFAULT NULL,
  sm7 BIGINT DEFAULT NULL,
  sm7_ba BIGINT DEFAULT NULL,
  post_triggers_ran SMALLINT NOT NULL DEFAULT 0,
  
  FOREIGN KEY (previous_block_id) REFERENCES block (id) ON DELETE CASCADE,
  FOREIGN KEY (next_block_id) REFERENCES block (id) ON DELETE SET NULL
);

DROP TABLE IF EXISTS peer;

CREATE TABLE peer (
  address VARCHAR(100) NOT NULL,
  PRIMARY KEY (address)
);

DROP TABLE IF EXISTS transaction;

CREATE TABLE transaction (
  db_id BIGSERIAL PRIMARY KEY,
  id BIGINT NOT NULL UNIQUE,
  deadline SMALLINT NOT NULL,
  sender_public_key BYTEA NOT NULL,
  recipient_id BIGINT DEFAULT NULL,
  amount BIGINT NOT NULL,
  fee BIGINT NOT NULL,
  height INTEGER NOT NULL,
  block_id BIGINT NOT NULL,
  signature BYTEA DEFAULT NULL,
  timestamp INTEGER NOT NULL,
  type SMALLINT NOT NULL,
  subtype SMALLINT NOT NULL,
  sender_id BIGINT NOT NULL,
  block_timestamp INTEGER NOT NULL,
  full_hash BYTEA NOT NULL,
  referenced_transaction_fullhash BYTEA DEFAULT NULL,
  attachment_bytes BYTEA,
  version SMALLINT NOT NULL,
  has_message BOOLEAN NOT NULL DEFAULT FALSE,
  has_encrypted_message BOOLEAN NOT NULL DEFAULT FALSE,
  has_public_key_announcement BOOLEAN NOT NULL DEFAULT FALSE,
  ec_block_height INTEGER DEFAULT NULL,
  ec_block_id BIGINT DEFAULT NULL,
  has_encrypttoself_message BOOLEAN NOT NULL DEFAULT FALSE,
  CONSTRAINT constraint_ff FOREIGN KEY (block_id) REFERENCES block (id) ON DELETE CASCADE
);
--
-- Table structure for table `unconfirmed_transaction` 
--





/*CONVERSION EFFORT STOPS HERE FOR NOW */





DROP TABLE IF EXISTS `unconfirmed_transaction`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `unconfirmed_transaction` (
  `db_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `id` bigint(20) NOT NULL,
  `expiration` int(11) NOT NULL,
  `transaction_height` int(11) NOT NULL,
  `fee_per_byte` bigint(20) NOT NULL,
  `timestamp` int(11) NOT NULL,
  `transaction_bytes` blob NOT NULL,
  `height` int(11) NOT NULL,
  PRIMARY KEY (`db_id`),
  UNIQUE KEY `unconfirmed_transaction_id_idx` (`id`),
  KEY `unconfirmed_transaction_height_fee_timestamp_idx` (`transaction_height`,`fee_per_byte`,`timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;
/*!40101 SET character_set_client = @saved_cs_client */;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;
/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

CREATE TABLE relons (
    transaction_id BIGINT(20) NOT NULL,
    from_nid BIGINT(20) NOT NULL DEFAULT 0,
    type TINYINT(1) NOT NULL DEFAULT 0,
    reln BIGINT(20) NOT NULL DEFAULT 0,
    to_type TINYINT(1) NOT NULL DEFAULT 0,
    to_a BIGINT(20) NULL DEFAULT NULL,
    to_s VARCHAR(255) NULL DEFAULT NULL,
    height INT(11) NULL DEFAULT 0,
    firstseen_tis TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    rorigin TINYINT(1) NOT NULL DEFAULT 0,
    annies BIGINT(20) NULL DEFAULT NULL,
    relon_sponsor BIGINT(20) NULL DEFAULT NULL,
    sys_ref_txid BIGINT(20) NULL DEFAULT NULL,
    hg_dependency_txid BIGINT(20) NULL DEFAULT NULL,
    flathexint INT NULL DEFAULT NULL,
    PRIMARY KEY (transaction_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE relons_payment (
    transaction_id BIGINT(20) NOT NULL,
    from_nid BIGINT(20) NOT NULL DEFAULT 0,
    type TINYINT(1) NOT NULL DEFAULT 0,
    reln BIGINT(20) NOT NULL DEFAULT 0,
    to_type TINYINT(1) NOT NULL DEFAULT 0,
    to_a BIGINT(20) NULL DEFAULT NULL,
    to_s VARCHAR(255) NULL DEFAULT NULL,
    height INT(11) NULL DEFAULT 0,
    firstseen_tis TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    rorigin TINYINT(1) NOT NULL DEFAULT 0,
    annies BIGINT(20) NULL DEFAULT NULL,
    relon_sponsor BIGINT(20) NULL DEFAULT NULL,
    sys_ref_txid BIGINT(20) NULL DEFAULT NULL,
    hg_dependency_txid BIGINT(20) NULL DEFAULT NULL,
    PRIMARY KEY (transaction_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE relons_awareness (
    transaction_id BIGINT(20) NOT NULL,
    from_nid BIGINT(20) NOT NULL DEFAULT 0,
    reln BIGINT(20) NOT NULL DEFAULT 0,
    to_type TINYINT(1) NOT NULL DEFAULT 0,
    to_a BIGINT(20) NULL DEFAULT NULL,
    to_s VARCHAR(255) NULL DEFAULT NULL,
    height INT(11) NULL DEFAULT 0,
    firstseen_tis TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (transaction_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE relons_this_annode_only (
    transaction_id BIGINT(20) NOT NULL,
    ntype TINYINT NULL DEFAULT NULL,
    be BIGINT(20) NOT NULL DEFAULT 0,
    from_nid BIGINT(20) NOT NULL DEFAULT 0,
    type TINYINT(1) NOT NULL DEFAULT 0,
    reln BIGINT(20) NOT NULL DEFAULT 0,
    to_type TINYINT(1) NOT NULL DEFAULT 0,
    to_a BIGINT(20) NULL DEFAULT NULL,
    to_s VARCHAR(255) NULL DEFAULT NULL,
    height INT(11) NULL DEFAULT 0,
    firstseen_tis TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    annies BIGINT(20) NULL DEFAULT NULL,
    sys_ref_txid BIGINT(20) NULL DEFAULT NULL,
    PRIMARY KEY (transaction_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE INDEX IF NOT EXISTS fn_rtaox ON relons_this_annode_only (from_nid);
CREATE INDEX IF NOT EXISTS rn_rtaox ON relons_this_annode_only (reln);
CREATE INDEX IF NOT EXISTS t_rtaox ON relons_this_annode_only (type);
CREATE INDEX IF NOT EXISTS nt_rtaox ON relons_this_annode_only (ntype);
CREATE INDEX IF NOT EXISTS tt_taox ON relons_this_annode_only (to_type);
CREATE INDEX IF NOT EXISTS ts_taox ON relons_this_annode_only (to_s);
CREATE INDEX IF NOT EXISTS ta_taox ON relons_this_annode_only (to_a);
CREATE INDEX IF NOT EXISTS b_taox ON relons_this_annode_only (be);


CREATE TABLE IF NOT EXISTS collab2 (
    transaction_id BIGINT NOT NULL,
    height INT NOT NULL DEFAULT 0,
    latest TINYINT NOT NULL DEFAULT 1,
    from_nid BIGINT(20) NOT NULL DEFAULT 0,
    type TINYINT(1) NOT NULL DEFAULT 0,
    reln BIGINT(20) NOT NULL DEFAULT 0,
    to_type TINYINT NOT NULL DEFAULT 0,
    to_a BIGINT(20) NULL DEFAULT NULL,
    to_s VARCHAR(254) NULL DEFAULT NULL,
    collaborator BIGINT(20) NOT NULL DEFAULT 0,
    timeinsecs TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    status_txid BIGINT(20) NULL DEFAULT NULL,
    nid_owner BIGINT(20) NULL DEFAULT NULL,
    status_text VARCHAR(1) NULL DEFAULT NULL,
    be BIGINT(20) NULL DEFAULT NULL,
    flathexint INT NULL DEFAULT NULL,
    collab_type TINYINT NOT NULL DEFAULT 0,
    PRIMARY KEY (transaction_id, height)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE aplex (
    id BIGINT(20) NOT NULL,
    annies_in BIGINT(20) NOT NULL DEFAULT 0,
    fire BIGINT(20) NOT NULL DEFAULT 0,
    pos INT(11) NOT NULL DEFAULT 0,
    neg INT(11) NOT NULL DEFAULT 0,
    neu INT(11) NOT NULL DEFAULT 0,
    last_update_h INT(11) NOT NULL DEFAULT 0,
    id_type TINYINT(1) NOT NULL DEFAULT 0,
    PRIMARY KEY (id, id_type)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE IF NOT EXISTS anneid (
    nid BIGINT(20) NOT NULL,
    andy_actions INT NULL DEFAULT 0,
    relons_sponsored INT NULL DEFAULT 0,
    hanais INT NULL DEFAULT 0,
    sponsored_neurons INT NULL DEFAULT 0,
    did_annex INT NULL DEFAULT 0,
    got_annexed INT NULL DEFAULT 0, 
    blocks_mined INT NULL DEFAULT 0,
    share_mines INT NULL DEFAULT 0,
    boostybacks_won BIGINT(20) NULL DEFAULT 0,  
    PRIMARY KEY (nid)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE anne_auth (
    aid BIGINT(20) NOT NULL,
    master_recovery_hash VARCHAR(254) NULL default NULL,
    master_recovery_salted_pw VARCHAR(254) NULL default NULL,
    encrypted_sk VARCHAR(254) NULL default NULL,
    sk VARCHAR(64) NULL default NULL,
    nonce VARCHAR(254) NULL default NULL,
    next_proof_id INT default NULL,
    logins INT NULL default NULL,
    creation_time TIMESTAMP NULL default CURRENT_TIMESTAMP(),
    last_time TIMESTAMP NULL default CURRENT_TIMESTAMP(),
    PRIMARY KEY (aid)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE neurons (
    nid BIGINT(20) NOT NULL,
    height INT NOT NULL DEFAULT 0,
    anbl_id BIGINT(20) NULL DEFAULT NULL,
    be BIGINT(20) NULL DEFAULT NULL,
    owned_by BIGINT(20) NULL DEFAULT NULL,
    sponsored_by BIGINT(20) NULL DEFAULT NULL,
    origin TINYINT NULL DEFAULT NULL,
    ntype TINYINT NULL DEFAULT NULL,
    is_active TINYINT NOT NULL DEFAULT 1,
    freeze TINYINT NOT NULL DEFAULT 0,
    latest TINYINT NOT NULL DEFAULT 1,
    prev_annex_price BIGINT(20) NOT NULL DEFAULT 0,
    prev_annex_hash VARBINARY(32) NULL DEFAULT NULL,
    boosties BIGINT(20) NOT NULL DEFAULT 0,
    price_lvl INT(11) NOT NULL DEFAULT 0,
    spawner_txid BIGINT(20) NULL DEFAULT NULL,
    confirmed TINYINT NOT NULL DEFAULT 0,
    
    PRIMARY KEY (nid, height, latest)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE bes (
    nid BIGINT(20) NOT NULL,
    be BIGINT(20) NULL DEFAULT NULL,
    bem1 BIGINT(20) NULL DEFAULT NULL,
    bem2 BIGINT(20) NULL DEFAULT NULL,
    bem3 BIGINT(20) NULL DEFAULT NULL,
    bem4 BIGINT(20) NULL DEFAULT NULL,
    bem5 BIGINT(20) NULL DEFAULT NULL,
    bem6 BIGINT(20) NULL DEFAULT NULL,
    bem7 BIGINT(20) NULL DEFAULT NULL,
    bem8 BIGINT(20) NULL DEFAULT NULL,
    bem9 BIGINT(20) NULL DEFAULT NULL,
    bem10 BIGINT(20) NULL DEFAULT NULL,
    bem11 BIGINT(20) NULL DEFAULT NULL,
    bem12 BIGINT(20) NULL DEFAULT NULL,
    PRIMARY KEY (nid)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE IF NOT EXISTS lnots (
    txid BIGINT(20) NOT NULL,
    asset_nid BIGINT(20) NOT NULL,
    area_nid BIGINT(20) NOT NULL,
    who_nid BIGINT(20) NOT NULL,
    from_who_nid BIGINT(20) NOT NULL,
    msg VARCHAR(254) NULL DEFAULT NULL,
    height INT(11) NULL DEFAULT 0,
    active TINYINT NULL DEFAULT 1,
    PRIMARY KEY (txid, asset_nid, area_nid, who_nid)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE IF NOT EXISTS localannode_custodial (
    custodial_nid BIGINT(20) NOT NULL,
    class_nid BIGINT(20) NOT NULL,
    owner_nid BIGINT(20) NOT NULL,
    seed VARCHAR(128) NOT NULL,
    height INT(11) NULL DEFAULT 0,
    active TINYINT NULL DEFAULT 1,
    PRIMARY KEY (custodial_nid)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE blobs (
    blob_id INT(10) NOT NULL AUTO_INCREMENT,
    rid BIGINT(20) NOT NULL DEFAULT 0,
    blob_data VARCHAR(256) NULL DEFAULT NULL,
    PRIMARY KEY (blob_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE `anbl` (
  `anbl_id` bigint(20) NOT NULL AUTO_INCREMENT,
  `anblstr` varchar(63) NOT NULL,
  `annum` int(10) DEFAULT NULL,
  PRIMARY KEY (`anbl_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE TABLE anblelons (
    anblelons_id BIGINT(20) NOT NULL AUTO_INCREMENT,
    anbl_id BIGINT(20) NOT NULL,
    nid BIGINT(20) NOT NULL,
    PRIMARY KEY (anblelons_id)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_520_ci;

CREATE INDEX IF NOT EXISTS anblelon_nidX ON anblelons (nid);
CREATE INDEX IF NOT EXISTS anblelon_anblidX ON anblelons (anbl_id);

CREATE TABLE achat_session (
    sesh_id BIGINT(20) NOT NULL AUTO_INCREMENT,
    sesh_name VARCHAR(128) NULL DEFAULT NULL,
    sesh_topic_nid BIGINT(20) NULL DEFAULT NULL,
    chat_permit TINYINT NULL DEFAULT 1,
    author_nid BIGINT(20) NOT NULL,
    txid_ref BIGINT(20) NULL DEFAULT NULL,
    block_start INT(11) NOT NULL,
    PRIMARY KEY (sesh_id)
);

CREATE TABLE achat_participants (
    sesh_id BIGINT(20) NOT NULL,
    sesh_participant_id BIGINT(20) NOT NULL,
    PRIMARY KEY (sesh_id, sesh_participant_id)
);

CREATE TABLE achat_msg (
    msg_id BIGINT(20) NOT NULL AUTO_INCREMENT,
    sesh_id BIGINT(20) NOT NULL,
    from_nid BIGINT(20) NOT NULL,
    to_nid BIGINT(20) NOT NULL,
    direction TINYINT NULL DEFAULT 1,
    msg VARCHAR(256) NULL DEFAULT NULL,
    height INT(11) NULL DEFAULT 0,
    PRIMARY KEY (msg_id)
);


CREATE TABLE IF NOT EXISTS account_balance (db_id bigint(20) NOT NULL AUTO_INCREMENT,
    id bigint(20) NOT NULL,
    balance bigint(20) NOT NULL,
    unconfirmed_balance bigint(20) NOT NULL,
    forged_balance bigint(20) NOT NULL,
    height INT NOT NULL, latest BOOLEAN NOT NULL DEFAULT TRUE,
    PRIMARY KEY (`db_id`));

CREATE OR REPLACE
ALGORITHM = MERGE VIEW `achat_overview` AS
select
    `achat_session`.`sesh_id` AS `sesh_id`,
    `achat_session`.`sesh_name` AS `sesh_name`,
    `achat_session`.`sesh_topic_nid` AS `sesh_topic_nid`,
    `achat_session`.`chat_permit` AS `chat_permit`,
    `achat_session`.`author_nid` AS `author_nid`,
    `achat_session`.`txid_ref` AS `txid_ref`,
    `achat_session`.`block_start` AS `block_start`,
    `achat_participants`.`sesh_participant_id` AS `sesh_participant_id`
from
    (`achat_session`
join `achat_participants` on
    (`achat_session`.`sesh_id` = `achat_participants`.`sesh_id`));


CREATE OR REPLACE
ALGORITHM = MERGE VIEW `anbls` AS
select
    `anbl`.`anbl_id` AS `anbl_id`,
    `anbl`.`anblstr` AS `anblstr`,
    `anbl`.`annum` AS `annum`,
    `anblelons`.`nid` AS `nid`
from
    (`anbl`
left join `anblelons` on
    (`anbl`.`anbl_id` = `anblelons`.`anbl_id`));


CREATE OR REPLACE
ALGORITHM = MERGE VIEW `beline` AS
select
    `neurons`.`nid` AS `nid`,
    `neurons`.`anbl_id` AS `anbl_id`,
    `neurons`.`owned_by` AS `owned_by`,
    `neurons`.`sponsored_by` AS `sponsored_by`,
    `neurons`.`origin` AS `origin`,
    `neurons`.`ntype` AS `ntype`,
    `neurons`.`freeze` AS `freeze`,
    `bes`.`be` AS `be`,
    `bes`.`bem1` AS `bem1`,
    `bes`.`bem2` AS `bem2`,
    `bes`.`bem3` AS `bem3`,
    `bes`.`bem4` AS `bem4`,
    `bes`.`bem5` AS `bem5`,
    `bes`.`bem6` AS `bem6`,
    `bes`.`bem7` AS `bem7`,
    `bes`.`bem8` AS `bem8`,
    `bes`.`bem9` AS `bem9`,
    `bes`.`bem10` AS `bem10`,
    `bes`.`bem11` AS `bem11`,
    `bes`.`bem12` AS `bem12`,
    `anbl`.`anblstr` AS `text`
from
    ((`neurons`
left join `bes` on
    (`neurons`.`nid` = `bes`.`nid`))
left join `anbl` on
    (`anbl`.`anbl_id` = `neurons`.`anbl_id`))
where
    `neurons`.`is_active` = 1
    and `neurons`.`latest` = 1;


CREATE OR REPLACE
ALGORITHM = MERGE VIEW `naplex` AS
select
    `neurons`.`nid` AS `nid`,
    `neurons`.`anbl_id` AS `anbl_id`,
    `neurons`.`be` AS `be`,
    `neurons`.`owned_by` AS `owned_by`,
    `neurons`.`sponsored_by` AS `sponsored_by`,
    `neurons`.`origin` AS `origin`,
    `neurons`.`ntype` AS `ntype`,
    `neurons`.`is_active` AS `is_active`,
    `neurons`.`freeze` AS `freeze`,
    `neurons`.`height` AS `height`,
    `aplex`.`annies_in` AS `annies_in`,
    `aplex`.`fire` AS `fire`,
    `neurons`.`prev_annex_price` AS `prev_annex_price`,
    `neurons`.`prev_annex_hash` AS `prev_annex_hash`,
    `neurons`.`boosties` AS `boosties`,
    `neurons`.`price_lvl` AS `price_lvl`,
    `aplex`.`pos` AS `pos`,
    `aplex`.`neg` AS `neg`,
    `aplex`.`neu` AS `neu`,
    `aplex`.`last_update_h` AS `last_update_h`,
    `anbl`.`anblstr` AS `anblstr`,
    `anbl`.`annum` AS `annum`
from
    ((`neurons`
left join `aplex` on
    (`neurons`.`nid` = `aplex`.`id`))
left join `anbl` on
    (`anbl`.`anbl_id` = `neurons`.`anbl_id`))
where
    `neurons`.`is_active` = 1
    and `neurons`.`latest` = 1;


CREATE OR REPLACE
ALGORITHM = MERGE VIEW `narr` AS
select
    `neurons`.`nid` AS `nid`,
    `neurons`.`anbl_id` AS `anbl_id`,
    `neurons`.`be` AS `be`,
    `neurons`.`owned_by` AS `owned_by`,
    `neurons`.`sponsored_by` AS `sponsored_by`,
    `neurons`.`origin` AS `origin`,
    `neurons`.`ntype` AS `ntype`,
    `neurons`.`freeze` AS `freeze`,
    `relons`.`transaction_id` AS `transaction_id`,
    `relons`.`from_nid` AS `from_nid`,
    `relons`.`type` AS `type`,
    `relons`.`reln` AS `reln`,
    `relons`.`to_type` AS `to_type`,
    `relons`.`to_a` AS `to_a`,
    `relons`.`to_s` AS `to_s`,
    `relons`.`height` AS `height`,
    `relons`.`firstseen_tis` AS `firstseen_tis`,
    `relons`.`rorigin` AS `rorigin`,
    `relons`.`annies` AS `annies`,
    `relons`.`relon_sponsor` AS `relon_sponsor`,
    `relons`.`sys_ref_txid` AS `sys_ref_txid`,
    `relons`.`flathexint` AS `flathexint`,
    `anbl`.`anblstr` AS `text`
from
    ((`neurons`
left join `relons` on
    (`neurons`.`nid` = `relons`.`from_nid`))
left join `anbl` on
    (`anbl`.`anbl_id` = `neurons`.`anbl_id`))
where
    `neurons`.`is_active` = 1
    and `neurons`.`latest` = 1;

CREATE OR REPLACE
ALGORITHM = MERGE VIEW `NIHG` AS
select
    `transaction`.`id` AS `id`,
    `transaction`.`block_id` AS `block_id`,
    `transaction`.`height` AS `height`,
    `transaction`.`type` AS `type`,
    `transaction`.`subtype` AS `subtype`
from
    (`transaction`
left join `relons` on
    (`transaction`.`id` = `relons`.`transaction_id`))
where
    `relons`.`transaction_id` is null;
    

CREATE INDEX IF NOT EXISTS aplxid ON aplex (id);
CREATE INDEX IF NOT EXISTS tx_sender_type ON transaction (sender_id, type);
CREATE INDEX IF NOT EXISTS account_balance_id_balance_height_idx ON account_balance (id, balance, height DESC);
CREATE INDEX IF NOT EXISTS account_balance_id_latest_idx ON account_balance(id, latest);
CREATE INDEX IF NOT EXISTS anblstrx ON anbl (anblstr);
CREATE INDEX IF NOT EXISTS from_nidx ON relons (from_nid);
					
CREATE TABLE IF NOT EXISTS relons_a2a (
    transaction_id BIGINT(20) NOT NULL,
    from_nid BIGINT(20) NOT NULL DEFAULT 0,
    type TINYINT(1) NOT NULL DEFAULT 0,
    reln BIGINT(20) NOT NULL DEFAULT 0,
    to_type TINYINT(1) NOT NULL DEFAULT 0,
    to_a BIGINT(20) NULL DEFAULT NULL,
    to_s VARCHAR(255) NULL DEFAULT NULL,
    height INT(11) NULL DEFAULT 0,
    firstseen_tis TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    rorigin TINYINT(1) NOT NULL DEFAULT 0,
    annies BIGINT(20) NULL DEFAULT NULL,
    relon_sponsor BIGINT(20) NULL DEFAULT NULL,
    sys_ref_txid BIGINT(20) NULL DEFAULT NULL,
    hg_dependency_txid BIGINT(20) NULL DEFAULT NULL,
    flathexint INT NULL DEFAULT NULL,
    PRIMARY KEY (transaction_id)
);

CREATE TABLE IF NOT EXISTS relons_awareness (
    transaction_id BIGINT(20) NOT NULL,
    from_nid BIGINT(20) NOT NULL DEFAULT 0,
    type TINYINT(1) NOT NULL DEFAULT 0,
    reln BIGINT(20) NOT NULL DEFAULT 0,
    to_type TINYINT(1) NOT NULL DEFAULT 0,
    to_a BIGINT(20) NULL DEFAULT NULL,
    to_s VARCHAR(255) NULL DEFAULT NULL,
    height INT(11) NULL DEFAULT 0,
    firstseen_tis TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    rorigin TINYINT(1) NOT NULL DEFAULT 0,
    annies BIGINT(20) NULL DEFAULT NULL,
    relon_sponsor BIGINT(20) NULL DEFAULT NULL,
    sys_ref_txid BIGINT(20) NULL DEFAULT NULL,
    hg_dependency_txid BIGINT(20) NULL DEFAULT NULL,
    flathexint INT NULL DEFAULT NULL,
    PRIMARY KEY (transaction_id)
);
